OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Liegts (Mantota atļauja)",
    "Allowed (Inherited permission)" : "Atļauts (Mantota atļauja)",
    "Denied" : "Liegts",
    "Allowed" : "Atļauts",
    "Access denied" : "Piekļuve liegta",
    "Deny" : "Noraidīt",
    "Allow" : "Atļaut",
    "Group" : "Grupa",
    "Team" : "Komanda",
    "Read" : "Lasīt",
    "Write" : "Rakstīt",
    "Create" : "Izveidot",
    "Delete" : "Izdzēst",
    "Share" : "Koplietot",
    "You" : "Tu",
    "Remove access rule" : "Noņemt piekļuves kārtulu",
    "Add group" : "Pievienot grupu",
    "Unlimited" : "Neierobežota",
    "Delete \"{folderName}\"?" : "Izdzēst \"{folderName}\"?",
    "Folder name" : "Mapes nosaukums",
    "Quota" : "Kvota",
    "Advanced Permissions" : "Papildu atļaujas",
    "Previous" : "Iepriekšējā",
    "User" : "Lietotājs",
    "Unknown" : "Nezināms",
    "None" : "Nekas",
    "{size} used" : "Izmantoti {size}",
    "Unset" : "Neuzstādīts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
